@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "dynaring" "0.4"
+(define-package "dynaring" "20251104.1606"
   "A dynamically sized ring structure."
   '((emacs "25.1"))
   :url "https://github.com/countvajhula/dynaring"
-  :commit "42333fcb734f675cab5d25d1b9d142d502914388"
-  :revdesc "0.4-0-g42333fcb734f"
+  :commit "d74e4f36da97a64baa023e5b2519bfaac7d8b02b"
+  :revdesc "d74e4f36da97"
   :authors '(("Mike Mattie" . "codermattie@gmail.com")
              ("Sid Kasivajhula" . "sid@countvajhula.com"))
   :maintainers '(("Sid Kasivajhula" . "sid@countvajhula.com")))
